.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2018-01-05)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.1.0...v0.2.0>`_

* Added REST API filters.
* Added URLs to pubmed article and NCBI utils.

0.2.1 (2018-01-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.2.0...v0.2.1>`_

* Fixed issues with migrations

0.2.2 (2018-01-12)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.2.1...v0.2.2>`_

* Fixed route names for SimpleRouter.

0.3.0 (2018-02-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.2.2...v0.3.0>`_

* updated requirements to the latest.

0.4.0 (2018-04-03)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.3.0...v0.4.0>`_

* Added support for GraphQL

0.5.0 (2018-04-07)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.4.0...v0.5.0>`_

* Added support for Django 2.0 and Python 3.6
* Dropped support for Django < 1.11 and Python 2.7, 3.3, 3.4

0.5.1 (2018-04-18)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.5.0...v0.5.1>`_

* Updated 3rd party libs
